==> image_processor_webp-1.0.4.tar.gz: image_processor_webp/src/EventSubscriber/ImageModifyResponseSubscriber.php <==
<?php

declare(strict_types=1);

namespace Drupal\image_processor_webp\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannel;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Routing\AdminContext;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Event subscriber for modifying image responses to use WebP format.
 */
class ImageModifyResponseSubscriber implements EventSubscriberInterface {

  /**
   * Provides context to determine if the current route is an admin route.
   *
   * @var \Drupal\Core\Routing\AdminContext
   */
  private AdminContext $adminContext;

  /**
   * Config factory interface for accessing configuration settings.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private ConfigFactoryInterface $configFactory;

  /**
   * Logger for logging warnings and errors.
   *
   * @var \Drupal\Core\Logger\LoggerChannel
   */
  private LoggerChannel $logger;

  /**
   * Constructs a new ImageModifyResponseSubscriber.
   *
   * @param \Drupal\Core\Routing\AdminContext $admin_context
   *   The admin context service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger factory service.
   */
  public function __construct(
    AdminContext $admin_context,
    ConfigFactoryInterface $config_factory,
    LoggerChannelFactoryInterface $logger_factory
  ) {
    $this->adminContext = $admin_context;
    $this->configFactory = $config_factory;
    $this->logger = $logger_factory->get('image_processor_webp');
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      KernelEvents::RESPONSE => ['onResponse', 0],
    ];
  }

  /**
   * Modifies the response to include WebP format images if enabled.
   *
   * @param \Symfony\Component\HttpKernel\Event\ResponseEvent $event
   *   The response event.
   */
  public function onResponse(ResponseEvent $event): void {
    $config = $this->configFactory->get('image_processor_webp.settings');
    if (!$config->get('preprocess_enabled')) {
      return;
    }

    if ($this->adminContext->isAdminRoute()) {
      return;
    }

    $request = $event->getRequest();
    $currentPath = $request->getPathInfo();
    if (strpos($currentPath, 'views/ajax') !== FALSE) {
      return;
    }

    $response = $event->getResponse();
    $html = $response->getContent();

    if (!$html) {
      return;
    }

    $doc = new \DOMDocument();
    @$doc->loadHTML($html, LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);

    $images = $doc->getElementsByTagName('img');

    foreach ($images as $img) {
      $lazySrc = $img->getAttribute('data-src') ?: $img->getAttribute('data-lazyload');
      $src = $lazySrc ?: $img->getAttribute('src');

      // Přeskočení, pokud je zdrojový soubor ve formátu SVG.
      if (strtolower(pathinfo($src, PATHINFO_EXTENSION)) === 'svg' || $this->isExternalUrl($src)) {
        continue;
      }

      $format = $config->get('format');
      $path_parts = pathinfo($src);
      if (!array_key_exists('dirname', $path_parts)) {
        $this->logger->error('Missing dirname key: @key', ['@key' => json_encode($path_parts)]);

        continue;
      }

      $webp_path = trim($path_parts['dirname']) . '/' . $path_parts['filename'] . '.' . $format;

      $fullPath = $_SERVER['DOCUMENT_ROOT'] . $webp_path;
      $fullPath = urldecode($fullPath);

      if (file_exists($fullPath)) {
        $picture = $doc->createElement('picture');
        $source = $doc->createElement('source');
        $source->setAttribute('type', 'image/webp');

        if ($img->hasAttribute('class') && str_contains($img->getAttribute('class'), 'swiper-lazy')) {
          $source->setAttribute('class', 'swiper-lazy');
          $source->setAttribute('data-srcset', $webp_path);
        }
        else {
          $source->setAttribute('srcset', $webp_path);
        }

        $img_clone = $img->cloneNode();
        $picture->appendChild($source);
        $picture->appendChild($img_clone);
        $img->parentNode->replaceChild($picture, $img);
      }
      elseif ($config->get('log_missing_images')) {
        $this->logger->warning('Missing WEBP: @key', ['@key' => $fullPath]);
      }
    }

    $html = $doc->saveHTML();
    $response->setContent($html);
  }

  /**
   * Checks if a URL is external.
   *
   * @param string $url
   *   The URL to check.
   *
   * @return bool
   *   TRUE if the URL is external, FALSE otherwise.
   */
  private function isExternalUrl(string $url): bool {
    return (bool) preg_match('/^https?:\/\//', $url);
  }

}

==> image_processor_webp-1.0.5.tar.gz: image_processor_webp/src/EventSubscriber/ImageModifyResponseSubscriber.php <==
<?php

declare(strict_types=1);

namespace Drupal\image_processor_webp\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannel;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Routing\AdminContext;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Event subscriber for modifying image responses to use WebP format.
 */
class ImageModifyResponseSubscriber implements EventSubscriberInterface {

  /**
   * Provides context to determine if the current route is an admin route.
   *
   * @var \Drupal\Core\Routing\AdminContext
   */
  private AdminContext $adminContext;

  /**
   * Config factory interface for accessing configuration settings.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private ConfigFactoryInterface $configFactory;

  /**
   * Logger for logging warnings and errors.
   *
   * @var \Drupal\Core\Logger\LoggerChannel
   */
  private LoggerChannel $logger;

  /**
   * Constructs a new ImageModifyResponseSubscriber.
   *
   * @param \Drupal\Core\Routing\AdminContext $admin_context
   *   The admin context service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger factory service.
   */
  public function __construct(AdminContext $admin_context, ConfigFactoryInterface $config_factory, LoggerChannelFactoryInterface $logger_factory) {
    $this->adminContext = $admin_context;
    $this->configFactory = $config_factory;
    $this->logger = $logger_factory->get('image_processor_webp');
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      KernelEvents::RESPONSE => ['onResponse', 0],
    ];
  }

  /**
   * Modifies the response to include WebP format images if enabled.
   *
   * @param \Symfony\Component\HttpKernel\Event\ResponseEvent $event
   *   The response event.
   */
  public function onResponse(ResponseEvent $event): void {
    $config = $this->configFactory->get('image_processor_webp.settings');
    if (!$config->get('preprocess_enabled')) {
      return;
    }

    if ($this->adminContext->isAdminRoute()) {
      return;
    }

    $request = $event->getRequest();
    $currentPath = $request->getPathInfo();
    if (strpos($currentPath, 'views/ajax') !== FALSE) {
      return;
    }

    $response = $event->getResponse();
    $html = $response->getContent();

    if (!$html) {
      return;
    }

    $doc = new \DOMDocument();
    // cspell:disable-next-line
    @$doc->loadHTML($html, LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);

    $images = $doc->getElementsByTagName('img');

    foreach ($images as $img) {
      // cspell:disable-next-line
      $lazySrc = $img->getAttribute('data-src') ?: $img->getAttribute('data-lazyload');
      $src = $lazySrc ?: $img->getAttribute('src');

      // Skipping if the source file is in SVG format.
      if (strtolower(pathinfo($src, PATHINFO_EXTENSION)) === 'svg' || $this->isExternalUrl($src)) {
        continue;
      }

      $format = $config->get('format');
      $path_parts = pathinfo($src);
      if (!array_key_exists('dirname', $path_parts)) {
        $this->logger->error('Missing dirname key: @key', ['@key' => json_encode($path_parts)]);

        continue;
      }

      $webp_path = trim($path_parts['dirname']) . '/' . $path_parts['filename'] . '.' . $format;

      $fullPath = $_SERVER['DOCUMENT_ROOT'] . $webp_path;
      $fullPath = urldecode($fullPath);

      if (file_exists($fullPath)) {
        $picture = $doc->createElement('picture');
        $source = $doc->createElement('source');
        $source->setAttribute('type', 'image/webp');

        if ($img->hasAttribute('class') && str_contains($img->getAttribute('class'), 'swiper-lazy')) {
          $source->setAttribute('class', 'swiper-lazy');
          $source->setAttribute('data-srcset', $webp_path);
        }
        else {
          $source->setAttribute('srcset', $webp_path);
        }

        $img_clone = $img->cloneNode();
        $picture->appendChild($source);
        $picture->appendChild($img_clone);
        $img->parentNode->replaceChild($picture, $img);
      }
      elseif ($config->get('log_missing_images')) {
        $this->logger->warning('Missing WEBP: @key', ['@key' => $fullPath]);
      }
    }

    $html = $doc->saveHTML();
    $response->setContent($html);
  }

  /**
   * Checks if a URL is external.
   *
   * @param string $url
   *   The URL to check.
   *
   * @return bool
   *   TRUE if the URL is external, FALSE otherwise.
   */
  private function isExternalUrl(string $url): bool {
    return (bool) preg_match('/^https?:\/\//', $url);
  }

}
